#
# spec file for package govc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           govc
Version:        0.49.0
Release:        1.1
Summary:        vSphere CLI built on top of govmomi
License:        Apache-2.0
URL:            https://github.com/vmware/govmomi
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.21

%description
The CLI is designed to be a user friendly CLI alternative to the GUI and well suited for automation tasks. It also acts as a test harness for the govmomi APIs and provides working examples of how to use the APIs.

%prep
%autosetup -p 1 -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X github.com/vmware/govmomi/govc/flags.BuildVersion=%{version} \
   -X github.com/vmware/govmomi/govc/flags.BuildCommit=v%{version} \
   -X github.com/vmware/govmomi/govc/flags.BuildDate=$BUILD_DATE" \
   -o bin/govc ./govc/main.go

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE.txt
%{_bindir}/%{name}

%changelog
* Wed Mar 12 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.49.0:
  * chore: Update version.go for v0.49.0
  * build(deps): bump golang.org/x/text from 0.22.0 to 0.23.0
  * chore: Use cns Task helpers in govc volume commands
  * govc: add volume.rm -keep flag to retain backing disk
  * govc: add volume.extend command
  * vcsim: add vsan Datastore support
  * vcsim: remove simulator.Map package variable
  * fix: vcsim: extend PropertyCollector lock to avoid potential
    races
  * govc: add GPU commands
  * govc: add session.login -jwt option
  * vcsim: add query and metadata support for CNS Volume API
  * build(deps): bump github.com/google/go-cmp from 0.6.0 to 0.7.0
  * build(deps): bump golang.org/x/text from 0.21.0 to 0.22.0
  * fix: Drop operationID soap header for unsupported endpoints
  * govc: Rewrite kms.export URL to use the host we connected to
    vCenter with
  * govc: Add storage.policy.create '-e' option to enable
    encryption
* Wed Feb 12 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.48.1:
  * chore: Update version.go for v0.48.1
  * build(deps): bump golang.org/x/text from 0.21.0 to 0.22.0
  * fix: Drop operationID soap header for unsupported endpoints
  * govc: Rewrite kms.export URL to use the host we connected to
    vCenter with
  * govc: Add storage.policy.create '-e' option to enable
    encryption
* Tue Jan 28 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.48.0:
  * chore: Update version.go for v0.48.0
  * Add ResourcePool.resourceConfigSpecDetailed to missingSet
    filter
  * add delete flag for CnsContainerCluster type
  * vcsim: add env var for use with ssoadmin GetTrustedCertificates
  * govc: sha256 for session cache
  * api: add vlsm.GlobalObjectManager.List method
  * vcsim: add disk query and metadata support
  * govc: add disk.metadata ls and update commands
  * fix: add DirectPathProfileManager to mo registry
  * vcsim: fix save+load of Alarm objects
  * govc: enhance VAPI for vSphere Supervisor Services
  * vcsim: add ssoadmin GetTrustedCertificates method
  * vcsim: fix lookup service deferred registration
  * vcsim: add vslm VStorageObjectManager (aka FCD Global Catalog)
    support
  * fix: support multiple property.Collector.Retrieve base type
    fields
  * fix: Add session lookup fallback for soap header auth
  * vcsim: add DatastoreNamespaceManager Create/Delete directory
    methods
  * fix: govc: import.ovf remote support regression
  * goreleaser: remove brew tap setup
* Fri Jan  3 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.47.0:
  * chore: Update version.go for v0.47.0
  * govc: Update govc usage doc
  * api: Fix OVF param to use interface
  * api: Generate bindings for 9.0.0.0.rc1
  * api: Generate API with Broadcom header
  * api: Specify ruby bundler for api gen
  * api: Update gen/gen.sh for 9.0.0.0.rc1
  * api: Support podman for building api
  * api: Build api with Go 1.23.2
  * govc: add datastore.download -json support
  * chore: update copyright header
  * vcsim: create cls vmdk descriptor and backing files
  * vcsim: Improve sim for pub/sub content libs
  * govc: add -b flag to volume.ls
  * cns: add json tags
  * api: Support returning DS info when resolving lib stor
  * api: Support DC for ResolveLibItemStor
  * govc: add disk.ls '-a' flag
  * api: Support encode/decode OVF to JSON
  * govc: add datastore.ls -H option
  * fix: govc fix field.info name (-n flag) validation
  * fix: SOAP vcSessionCookie value must be from vim25.Client
  * api: Fix object.VirtualDiskManager::Copy
  * vcsim: make QueryVirtualDiskUuid() result stable
  * vcsim: add VirtualDiskManager.QueryVirtualDiskInfo
  * vcsim: fix object.save when run directly against ESX
  * vcsim: LicenseManager enhancements
  * api: Update OVF ToConfigSpec to handled unknown types
  * api: A generic copy function for vim25/types
  * govc: remove minimum API version check
  * api: add override mechanism for SOAP Header.Cookie
  * api: OVF to ConfigSpec
  * Deprecate haproxy with vSphere 9.0
  * fix: toolbox: add freebsd stub for fileExtendedInfoFormat
  * build(deps): bump golang.org/x/text from 0.18.0 to 0.21.0
  * fix: vcsim: swap order of xsi type attribute
  * api: Support OVF ResourceType enum
  * api: Update OVF parser to conform to spec
  * vcsim: add UpdateAssignedLicense method
  * fix: assert Entity interface in mo.Value()
  * api: move cli/host/esxcli.Command to cli/esx package
  * build(deps): bump github.com/stretchr/testify from 1.9.0 to
    1.10.0
  * vcsim: add esxcli support
  * fix: Property Collector updates should be triggered on the
    empty FilterSet
  * fix: vcsim: output signed byte in ByteSlice.MarshalXML
  * govc: Move govc commands into cli pkg
  * fix: govc: wire up flags for namespace service create
  * vcsim: Lock alpine image tag to non-latest tag
  * fix: vcsim: avoid possible panic when applying PropertyFilter
  * chore: Minimum version selection
  * cns: Support encryption/re-encryption of volumes
* Fri Dec 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.46.3:
  * chore: Update version.go for v0.46.3
  * fix: toolbox: add freebsd stub for fileExtendedInfoFormat
  * vcsim: fix object.save when run directly against ESX
  * vcsim: LicenseManager enhancements
  * fix: vcsim: swap order of xsi type attribute
  * govc: remove minimum API version check
  * vcsim: add UpdateAssignedLicense method
  * fix: assert Entity interface in mo.Value()
  * fix: Property Collector updates should be triggered on the
    empty FilterSet
* Wed Nov 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.46.2:
  * chore: Update version.go for v0.46.2
  * fix: vcsim: output signed byte in ByteSlice.MarshalXML
* Fri Nov 15 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.46.1:
  * chore: Update version.go for v0.46.1
  * fix: vcsim: avoid possible panic when applying PropertyFilter
  * cns: Support encryption/re-encryption of volumes
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.46.0:
  * chore: Update version.go for v0.46.0
  * govc: add vm.change -migrate-encryption and -ft-encryption-mode
    options
  * api: Support CnsBlockCreateSpec
  * api: support MOID conversion in Finder methods
  * govc: add '-I' flag to ls and find commands
  * fix: Set DuplicateName Object to duplicate object
  * chore: skip tests unless running docker on linux
  * fix: CreateSATAController to return error when no bus numbers
  * api: change ManagerKmip.IsValidKey to use QueryCryptoKeyStatus
  * vcsim: add QueryCryptoKeyStatus
  * govc: add kms.key commands
  * api: add crypto.ManagerKmip.QueryCryptoKeyStatus
  * fix: vcsim: avoid race in DestroyPropertyFilter
  * api: Fetch crypto key in GetVirtualDiskInfoByUUID
  * Fix error assertion in IsCertificateUntrusted
* Thu Oct 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.45.1:
  * chore: Update version.go for v0.45.1
  * Fix error assertion in IsCertificateUntrusted
* Tue Oct 22 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.45.0:
  * chore: Update version.go for v0.45.0
  * govc: rename 'object.collect' -> 'collect'
  * govc: display default provider in kms.ls output
  * fix: Add missing privileges in simulator role
  * fix: Cross-platform path handling
  * bug: Do not panic on fault.In for valid errs
  * govc: Add an unreleased folder.place command for
    PlaceVMsXCluster
  * fix: check controller type in simulator configureDevice
  * fix: update controller's device list in AssignController
  * govc: support use of service version via GOVC_VIM_VERSION env
    var
  * fix: ensure proper vSAN URI format in ResolveLibraryItemStorage
  * api: tags error handling
  * fix: Use absolute path for reading manifest
  * fix: Abort lease on upload failure
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.44.1:
  * chore: Update version.go for v0.44.1
  * fix: ensure proper vSAN URI format in ResolveLibraryItemStorage
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.44.0:
  * chore: Update version.go for v0.44.0
  * chore: fixup internal version
  * vcsim: lock ViewManager in RegisterObject callbacks
  * govc: update help url
  * build(deps): bump golang.org/x/text from 0.18.0 to 0.19.0
  * vcsim: add *Context param to UpdateObject interface method
  * govc: add vm.change -managed-by flag
  * vcsim: support clearing ManagedBy field
  * fix: synchronize access to session.Manager.userSession
  * examples: add ExampleListView_ofContainerView
  * vcsim: handle traversal spec object updates
  * vcsim: ModifyListView 'remove' does not return unresolved
    objects
  * chore: bump default ClientVersion
  * docs: sync CHANGELOG
  * chore: bump Go versions
  * chore: fix GH Action tag output param
  * docs: various updates
  * govc: add storage.policy.info flag to query IO filters
  * Use internalpbm namespace for PbmQueryIOFiltersFromProfileId
  * vcsim: override response namespace from struct tag
  * api: Update folder.PlaceVMsXCluster to support several
    placement types
  * api: disable http.Transport.ForceAttemptHTTP2 by default
  * vcsim: fix RelocateVM_Task related races
  * govc: add native kms provider support
  * api: add vapi/crypto package with support for native KMS
  * api: add rest.Client.DownloadAttachment method
  * api: extract NewDatastoreURL from Datastore.NewURL method
  * api: Support querying PBM profile for IOFILTERS
  * govc: add kms commands
  * chore: rename crypto.Manager RegisterKmipCluster >
    RegisterKmsCluster
  * vcsim: support cluster registration in RegisterKmipServer
  * vcsim: Gen enc key w default provider on createvm
  * api: Helpers for key management servers
  * chore: simplify error handling by using the new fault package
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.43.0:
  * chore: Update version.go for v0.43.0
  * api: Fault helpers
  * vcsim: Support PlaceVm with relocate placement type
  * Update library state info to content library API
  * vcsim: Support PlaceVm with reconfigure placement type
  * build(deps): bump golang.org/x/text from 0.17.0 to 0.18.0
  * chore: sync generated govc/USAGE.md
  * govc: add disk.create '-profile' flag
  * govc: add vm.disk.create '-profile' flag
  * govc: add vm.disk.attach '-profile' flag
  * chore: govc: add common StorageProfileFlag
  * api: add VirtualMachine.AddDeviceWithProfile method
  * vcsim: add VirtualMachine AttachDisk and DetachDisk methods
  * fix: vcsim: avoid possible race when encoding PropertyCollector
    response
  * build(deps): bump peter-evans/create-pull-request from 6 to 7
  * vcsim: Support VM crypto spec in vC Sim
  * Add BackingDiskPath to BackingObjectDetails
  * govc: Add '-size' flag to datastore.create
  * govc add disk.attach and disk.detach commands
  * api: VirtualMachine.AttachDisk unitNumber param is optional
  * api: ToString for vim types
  * vcsim: add namespace/registervm implementation
  * govc: add namespace.registervm command
  * api: add namespace.RegisterVM binding
  * api: Fix panic when encoding nil iface ptrs to JSON
  * govc: Support thick/eager disk opts on vm.create
  * fix: use complete InventoryPath in Datacenter.Folders
* Sat Aug 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.42.0:
  * chore: Update version.go for v0.42.0
  * api: update eam bindings to include authentication schema with
    eam-vcenter build 24075398 Closes: 3521
* Sat Aug 17 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.41.0:
  * chore: Update version.go for v0.41.0
  * api: OptionValues IsTrue|IsFalse
* Tue Aug 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.40.0:
  * chore: Update version.go for v0.40.0
  * examples: add ExampleCollector_WaitForUpdatesEx_pagination
  * vcsim: add SessionManager.ImpersonateUser method
  * govc: add session.login '-as' flag to impersonate user
  * api: add session.Manager.ImpersonateUser method
  * fix: govc object.collect truncation
  * vcsim: implement WaitForUpdatesEx pagination support
  * vcsim: add AlarmManager
  * govc: add alarm commands
  * api: add alarm package with helpers for AlarmManager and Alarms
  * govc: add event.post command
  * fix: govc: output Message field for 'EventEx' types
  * build(deps): bump golang.org/x/text from 0.16.0 to 0.17.0
  * vcsim: fix panic in CancelTask
  * govc: add library.sync '-f' flag to force sync file content
  * fix: restore govc import.spec DiskProvisioning default value
  * vcsim: add ovf DiskProvisioning validation
  * api: convert vSAN directory name to uuid in
    ResolveLibraryItemStorage
  * vcsim: add DatastoreNamespaceManager
  * govc: add library.info -S flag
  * review feedback
  * review feedback
  * implement capacityAllocationUnits parser
* Mon Jul 22 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.39.0:
  * chore: Update version.go for v0.39.0
  * api: use CheckTestType in compat and provisioning checkers
  * api: add sata controller
  * api: Exporting Unit field in MetricSeries struct for external
    use
  * chore: bump go version
  * govc: add vm.check commands
  * govc: add '-spec' flag to vm clone, migrate and create commands
  * govc: add vm.migrate -net flag
  * vcsim: add VmCompatibilityChecker and VmProvisioningChecker
  * refactor: make importing templates available as a lib
  * chore: fix codeql
  * vcsim: Add support for DRS automation levels
  * api: Add simulator test for GetVirtualDiskInfoByUUID
  * api: GetVirtualDiskInfoByUUID for getting capacity/size info
  * api: change CoresPerNumaNode to a pointer type
  * api: Add a method for extending VMDK
  * api: add ResolveLibraryItemStorage
  * fix: handle base types by default in mo.LoadObjectContent
  * vcsim: Re-enable TenantManager
* Tue Jun 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.38.0:
  * chore: Update version.go for v0.38.0
  * govc: add vsan.info -file-service-enabled flag
  * vcsim: add vSAN FileServiceConfig support
  * chore: make doc
  * govc: add host.tpm.info and host.tpm.report commands
  * vcsim: add HostCertificateManager
  * govc: add host.cert.info -show flag
  * fix: xml marshal byte array fields as vCenter does
  * govc: add storage.policy.create zonal option
  * api: EnsureDisksHaveControllers helper
  * api: OptionValueList helper
  * govc: add '-storage' flag to namespace.create and
    namespace.update commands
  * api: add storage_specs field to Namespace related structures
  * govc: add vm.create '-profile' and '-place' flags
  * api: add pbm.DatastoreMap for finding compatible Datastores
  * govc: Add feature to pass fullname and org for windows vm
    customization
  * fix: govc vm.disk.change should only modify CapacityInBytes
  * build(deps): bump goreleaser/goreleaser-action from 5 to 6
  * vcsim: add library item storage API support
  * nfc: Record the SSL thumbprint for the host the (device) URL
    refers to
  * vcsim: add PropertyCollector index support
  * vcsim: fix: ignore unknown refs in Datacenter.PowerOnMultiVM
  * api: HardwareVersion.IsSupported vs IsValid
  * feat: vSphere Zones API bindings
  * api: Add library item storage APIs
  * build(deps): bump nokogiri from 1.16.2 to 1.16.5 in /gen
  * api: Update ConfigInfoToConfigSpec
  * api: Update generated types
  * vcsim: Add PbmCheckCompatibility method in pbm simulator
  * api: add checksum validation in Content Library update session
    file API
  * vcsim: add HostVirtualNicManager
  * chore: govc: use generated enum lists
  * api: Generate enum consts with Values funcs
  * vcsim: fix ReconfigVM validation when changing disk size
  * api: add SSLCertificate to TransferEndpoint in content library
    API
  * build(deps): bump chuhlomin/render-template from 1.9 to 1.10
  * bugfix: Exclude ServerGUID from MOR comparison in WaitEx
* Wed Jun  5 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.37.3:
  * chore: Update version.go for v0.37.3
  * nfc: Record the SSL thumbprint for the host the (device) URL
    refers to
* Fri May 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.37.2:
  * chore: Update version.go for v0.37.2
  * vcsim: Add PbmCheckCompatibility method in pbm simulator
  * api: add checksum validation in Content Library update session
    file API
  * vcsim: fix ReconfigVM validation when changing disk size
  * api: add SSLCertificate to TransferEndpoint in content library
    API
* Thu Apr 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.37.1:
  * chore: Update version.go for v0.37.1
  * bugfix: Exclude ServerGUID from MOR comparison in WaitEx
* Sat Apr 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.37.0:
  * chore: Update version.go for v0.37.0
  * vcsim: toggle Content Library cached fields in sync and evict
    calls
  * govc: Add library.evict command
  * vcsim: add ExtensionManager.FindExtension method
  * build(deps): add vcsim to rpm
  * govc: add default output formatting for namespace commands
  * fix: make cns.Client independent of vim25.Client
  * api: use RetrievePropertiesEx in mo package functions
  * vcsim: RetrievePropertiesEx & ContinueRetrievePropertiesEx
  * api: change RetrieveProperties to collect results in batches
  * feat: Add VAPI bindings for guest namespaces and virtual
    machine classes
  * build(deps): enable rpm builds and add archs
  * api: move vim25.Client.UseServiceVersion to soap.Client
  * api: Expose vSphere API to evict subscribed content library
  * fix: vcsim: re-parent children in ResourcePool.Destroy
  * vcsim: add TaskHistoryCollector support
  * Remove deprecation for task.Wait and task.WaitForResult
  * govc: snapshot.tree json output to stdout
  * fix: endpoint url to bypass lookup service if envoy sidecar
    enabled
  * api: Add Downloadendpoint field in the library item file struct
  * vcsim: add TaskManager.CreateTask support
  * vcsim: add ExtensionManager support
  * build(deps): bump google.golang.org/protobuf in /hack/tools
  * Add support for SHA256 thumbprint based vCenter authentication
  * fix: lookup client to use envoy sidecar url if enabled
  * docs: update CHANGELOG
  * docs: update CONTRIBUTORS
* Wed Apr  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.36.3:
  * chore: Update version.go for v0.36.3
  * Remove deprecation for task.Wait and task.WaitForResult
* Sat Mar 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.36.2:
  * chore: Update version.go for v0.36.2
  * govc: snapshot.tree json output to stdout
  * fix: endpoint url to bypass lookup service if envoy sidecar
    enabled
  * api: Add Downloadendpoint field in the library item file struct
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.36.1:
  * chore: Update version.go for v0.36.1
  * Add support for SHA256 thumbprint based vCenter authentication
  * fix: lookup client to use envoy sidecar url if enabled
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.36.0:
  * chore: Update version.go for v0.36.0
  * Updating CONTRIBUTORS
  * fix: vcsim Fetch method causes runtime panic when property is
    not set
  * Add APIs for vLCM enablement on a cluster and base ESXi image
    selection
  * chore: bump Go versions
  * build(deps): bump github.com/stretchr/testify from 1.8.4 to
    1.9.0
  * Add API for vLCM - offline depots and cluster baseline images
  * chore: Better support for ESXi & HW versions
  * vcsim: Enhanced sim support for upgrade VM
  * fix: Update summary.config.hwVersion in simulator
  * test fixes
  * fix: govc: use session KeepAlive in library.export command
  * Add service locator to CNS RelocateVolume spec
  * Add  "AggregatedSnapshotCapacityInMb" to
    CnsSnapshotCreateResult and CnsSnapshotDeleteResult.
* Mon Feb 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.35.0:
  * chore: Update version.go for v0.35.0
  * docs: update release doc
  * chore: update CONTRIBUTORS
  * govc: json tag camelCase fixes
  * Add "AggregatedSnapshotCapacityInMb" to cnstype.
  * add -json to snapshot.tree
  * build(deps): bump nokogiri from 1.14.3 to 1.16.2 in /gen
  * api: Sim vm config.changeVersion & config.modified
  * build(deps): bump peter-evans/create-pull-request from 5 to 6
  * Re-enable PC updates for indexed properties
  * build(deps): bump andstor/file-existence-action from 2 to 3
  * build(deps): bump peter-evans/create-or-update-comment from 3
    to 4
  * Add new "UsedCapacityInMb" in struct "CnsBlockBackingDetails"
  * build(deps): bump github.com/google/uuid from 1.5.0 to 1.6.0
  * build(deps): bump actions/cache from 3 to 4
  * Self identify the executable making calls to vCenter
  * api: WaitForUpdatesEx & DestroyPropertyFilter
  * Changes to fix xml tag used for SnapshotId
  * vcsim: Fix -method-delay option to update task states
  * Fixes Missing Tags in AttachedTags
  * Changes to add CNS fault CnsSnapshotCreatedFault
  * build(deps): bump actions/upload-artifact from 3 to 4
  * build(deps): bump github/codeql-action from 2 to 3
  * build(deps): bump github.com/google/uuid from 1.4.0 to 1.5.0
  * build(deps): bump chuhlomin/render-template from 1.8 to 1.9
* Sat Jan 20 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package govc: vSphere CLI written in go
